Tutorials
=========

This folder contains several tutorials on how to use the GeoWATCH system to
train simple fusion models:

* Tutorial 1: `Toy RGB Tutorial <tutorial1_rgb_network.sh>`_

* Tutorial 2: `Toy MSI Tutorial <tutorial2_msi_network.sh>`_

* Tutorial 3: `Feature Fusion Tutorial <tutorial3_feature_fusion.sh>`_

* Tutorial 4: `Advanced Training <tutorial4_advanced_training.sh>`_

* Tutorial 5: `BAS Prediction <tutorial5_bas_prediction.sh>`_


TODO: tutorial about kwcoco (See docs for `kwcoco <https://gitlab.kitware.com/computer-vision/kwcoco>`_)


SeeAlso SMART-specific tutorials:

../docs/smart/smart_ac_tutorial.rst
../docs/smart/smart_ensemble_tutorial.rst
